/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, { useState, useEffect, useContext } from 'react';
import styled from 'styled-components'
import { apiUrl } from "../env";
import axios from "axios";
import mapaBrasil from '../img/mapa-brasil-line-icon.svg';
import Grid from '@material-ui/core/Grid';
import { Store } from '../Store';

export default function (props) {
  const { state } = useContext(Store)

  const [available_resources, setAvailableResources] = useState(0)
  const [month_publications, setMonthPublications] = useState(0)
  const [month_downloads, setMonthDownloads] = useState(0)

  const WINDOW_WIDTH = window.innerWidth

  useEffect(() => {
    axios.get(`${apiUrl}/statistics`)
      .then(
        (res) => {
          setAvailableResources(res.data.count)
          setMonthPublications(res.data.month_publications)
          setMonthDownloads(res.data.month_downloads)
        })
  }, [])

  return (
    <StatsTab contrast={state.contrast}>
      <link href="https://fonts.googleapis.com/css2?family=Roboto:wght@300&display=swap" rel="stylesheet" />
      <Grid container direction={WINDOW_WIDTH <= 670 ? "column" : "row"} justify="center" alignItems="center" spacing={3}>
        <Grid item>
          <Grid container direction="row" alignItems="center" spacing={2}>
            <Grid item>
              <img src={mapaBrasil} height="83px" alt="mapa do brasil" />
            </Grid>
            <Grid item>
              <Grid container direction="column">
                <StyledGridNumbers item style={{ textAlign: "center" }}>
                  {available_resources}
                </StyledGridNumbers>
                <StyledGridLabels item>
                  Recursos disponíveis
                </StyledGridLabels>
              </Grid>
            </Grid>
          </Grid>
        </Grid>
        <Grid item style={WINDOW_WIDTH <= 670 ? { width: "100%" } : null}>
          <StyledDivider />
        </Grid>
        <Grid item>
          <Grid container direction="row" alignItems="center" spacing={2}>
            <StyledGridLabels item>
              ESSE MÊS:
            </StyledGridLabels>

            <Grid item>
              <Grid container direction="column">
                <StyledGridNumbers item>
                  {month_downloads}
                </StyledGridNumbers>
                <StyledGridLabels item>
                  Baixados
                </StyledGridLabels>
              </Grid>
            </Grid>

            <Grid item>
              <Grid container direction="column">
                <StyledGridNumbers item>
                  {month_publications}
                </StyledGridNumbers>
                <StyledGridLabels item>
                  Publicados
                </StyledGridLabels>
              </Grid>
            </Grid>
          </Grid>
        </Grid>
      </Grid>
    </StatsTab>
  )

}

const StatsTab = styled.div`
    padding : 20px 0;
    color : #fff;
    border-top: ${props => props.contrast === "" ? "none" : "1px solid white"};
    border-bottom: ${props => props.contrast === "" ? "none" : "1px solid white"};
    background-color: ${props => props.contrast === "" ? "#00bcd4" : "black"};
    font-family: 'Roboto', sans-serif;
`
const StyledDivider = styled.div`
  border-bottom: 1px dotted white; 
  width: 80%;
  margin: 0 auto;  
  height: 1px;
  @media screen and (min-width : 670px) {
    border-right: 1px dotted white; 
    width: 1px; 
    height: 70.3px; 
  }
`
const StyledGridNumbers = styled(Grid)`
  text-align: center; 
  font-weight: 700;
  font-size: 26px;
  > p{
    font-family: 'Roboto', sans-serif;
  }
  @media screen and (min-width : 406px) {
    font-size: 3.571em;
  }
`

const StyledGridLabels = styled(Grid)`
  font-size: 16px; 
  font-weight: 300;
  @media screen and (min-width : 406px) {
    font-size: 1.285em;
  }
`