/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, { useState, useEffect } from 'react'
import PanelTemplateRede from '../PanelComponents/TemplateRede.js'
import { fetchAllRequest, getRequest } from '../../HelperFunctions/getAxiosConfig'
import LoadingSpinner from '../../LoadingSpinner.js'

export default function TabRede({ id, username, contrast }) {
  const [loading, handleLoading] = useState(true)

  const [errorInFollowing, setErrorInFollowing] = useState(false)
  const [errorInFollowers, setErrorInFollowers] = useState(false)

  const [followingList, setFollowing] = useState([])
  const [currFollowingLimit, setCurrFollowingLimit] = useState(12)
  const [loadingMoreFollowing, setLoadingFollowing] = useState(false)
  const [endOfFollowing, setEndOfFollowing] = useState(false)

  const [followersList, setFollowers] = useState([])
  const [currFollowerLimit, setFollowersLimit] = useState(12)
  const [loadingMoreFollowers, setLoadingMoreFollowers] = useState(false)
  const [endOfFollowers, setEndOfFollowers] = useState(false)

  const showMoreFollowing = (limite) => {
    setLoadingFollowing(true);
    const limit = limite;
    setCurrFollowingLimit(currFollowingLimit + limit)
    const url = `/users/${id}/following/User?offset=${currFollowingLimit}&limit=${limit}`;
    getRequest(url,
      (data) => {
        if (data.errors) {
          setLoadingFollowing(false);
          setEndOfFollowing(true);
          setErrorInFollowing(true);
        }
        else if (data.length >= 1) {
          let currData = [...followingList];
          currData = [...currData.concat(data)];
          setLoadingFollowing(false);
          setFollowing(currData);
        }
        else {
          setLoadingFollowing(false);
          setEndOfFollowing(true);
        }
      },
      (error) => {
        setLoadingFollowing(false);
        setEndOfFollowing(true);
        setErrorInFollowing(true);
      }
    )
  }

  const showMoreFollowers = (limite) => {
    setLoadingMoreFollowers(true);
    const limit = limite;
    setFollowersLimit(currFollowerLimit + limit)
    const url = `/users/${id}/followers?offset=${currFollowerLimit}&limit=${limit}`;
    getRequest(url,
      (data) => {
        if (data.errors) {
          setLoadingMoreFollowers(false);
          setEndOfFollowers(true);
          setErrorInFollowers(true);
        }
        else {
          if (data.length >= 1) {
            let currData = [...followersList];
            currData = [...currData.concat(data)];
            setLoadingMoreFollowers(false);
            setFollowers(currData);
          }
          else {
            setLoadingMoreFollowers(false);
            setEndOfFollowers(true)
          }
        }
      },
      (error) => {
        setLoadingMoreFollowers(false);
        setEndOfFollowers(true);
        setErrorInFollowers(true);
      }
    )
  }

  async function handleSuccess(responseArr, headersArr) {
    setErrorInFollowing(responseArr[0].errors ? true : false) // prevent of crashing the portal, do not remove it
    setErrorInFollowers(responseArr[1].errors ? true : false) // prevent of crashing the portal, do not remove it
    setFollowers(responseArr[0])
    setFollowing(responseArr[1])

    if (headersArr[1].has('X-Total-Count')) {
      setEndOfFollowing(headersArr[1].get('X-Total-Count'));
    }
    if (headersArr[0].has('X-Total-Count')) {
      setEndOfFollowers(headersArr[0].get('X-Total-Count'));
    }
    handleLoading(false)
  }

  function handleErrors() {
    setLoadingMoreFollowers(false);
    setEndOfFollowers(true);
    setErrorInFollowers(true);
  }

  useEffect(() => {
    handleLoading(true)

    const urls = [`/users/${id}/followers`, `/users/${id}/following/User`]

    fetchAllRequest(urls, handleSuccess, handleErrors)
  }, [])

  return (
    <>
      {
        loading ?
          (
            [
              <LoadingSpinner contrast={contrast} text={`Carregando dados de ${username}`} />
            ]
          )
          :
          (
            [
              <React.Fragment>
                <PanelTemplateRede
                  contrast={contrast}
                  title={`Seguidores de ${username}`}
                  length={followersList.length}
                  sliceArr={followersList}
                  showMore={showMoreFollowers}
                  follower={true}
                  end={endOfFollowers}
                  loadingMore={loadingMoreFollowers}
                  error={errorInFollowers}
                  noContentText={username + ' não possui nenhum seguidor'}
                />

                <PanelTemplateRede
                  contrast={contrast}
                  title={`${username} está seguindo`}
                  length={followingList.length}
                  sliceArr={followingList}
                  showMore={showMoreFollowing}
                  follower={false}
                  end={endOfFollowing}
                  loadingMore={loadingMoreFollowing}
                  error={errorInFollowing}
                  noContentText={username + ' não segue nenhum usuário'}
                />
              </React.Fragment>
            ]
          )
      }
    </>
  )
}
